/*
 * Algebraic manipulator externals.
 */

extern int		n_tokens;
extern int		n_equations;
extern int		cur_equation;

extern int		n_lhs[N_EQUATIONS];
extern int		n_rhs[N_EQUATIONS];

extern token_type	*lhs[N_EQUATIONS];
extern token_type	*rhs[N_EQUATIONS];

extern int		n_tlhs;
extern int		n_trhs;

extern token_type	*tlhs;
extern token_type	*trhs;

extern token_type	*scratch;

extern char		*var_names[MAX_VAR_NAMES];

extern int		case_sensitive_flag;
extern int		groupall;
extern int		in_calc_cmd;
extern int		preserve_roots;
extern int		true_modulus;
extern int		screen_columns;
extern int		screen_rows;
extern int		finance_option;
extern int		debug_level;
extern int		domain_check;
extern int		color_flag;
extern int		html_flag;
extern int		partial_flag;
extern int		symb_flag;
extern int		high_prec;
extern int		input_column;
extern int		sign_flag;
extern int		piping_in_flag;
extern char		*tmp_file;
extern double		small_epsilon;
extern double		epsilon;
extern char		var_str[];
extern char		prompt_str[];
extern char		*dir_path;

extern double		unique[];
extern int		ucnt[];
extern int		uno;

extern sign_array_type	sign_array;

extern FILE		*gfp;

extern jmp_buf		jmp_save;

extern int		test_mode;
